@@ -7,6 +7,7 @@ from bionetgen.tools import BNGPlotter
 from bionetgen.tools import BNGInfo
 from bionetgen.tools import BNGVisualize
 from bionetgen.tools import BNGCLI
+from bionetgen.tools import BNGGdiff
 
 import os, sys
 
@@ -112,3 +113,10 @@ def visualizeModel(config, args):
     config_bngpath = config.get("bionetgen", "bngpath")
     viz = BNGVisualize(inp, output=out, vtype=vtype, bngpath=config_bngpath)
     viz.run()
+
+
+def graphDiff(config, args):
+    # if you set args.bngpath it should take precedence
+    config_bngpath = config.get("bionetgen", "bngpath")
+    gdiff = BNGGdiff(args.input, args.input2, args.output, args.output2, args.mode)
+    gdiff.run()
