@@ -9,6 +9,7 @@ from .core.main import plotDAT
 from .core.main import runAtomizeTool
 from .core.main import printInfo
 from .core.main import visualizeModel
+from .core.main import graphDiff
 from .core.notebook import BNGNotebook
 
 # pull defaults defined in core/defaults
@@ -381,6 +382,63 @@ class BNGBase(cement.Controller):
         args = self.app.pargs
         visualizeModel(self.app.config, args)
 
+    @cement.ex(
+        help="A subcommand to compare two contact maps made by BioNetGen. "
+        + 'The default mode is "matrix" mode and will generate 4 graphs, two for each individual input '
+        + "recolored, one for input 1 - input 2 and one for input 2 - input 1. This can be used to find "
+        + "differences and communalities between two BNGL models of the same process. ",
+        arguments=[
+            (
+                ["-i", "--input"],
+                {
+                    "help": "Path to the first graphml file to diff",
+                    "default": None,
+                    "type": str,
+                    "required": True,
+                },
+            ),
+            (
+                ["-i2", "--input2"],
+                {
+                    "help": "Path to the second graphml file to diff",
+                    "default": None,
+                    "type": str,
+                    "required": True,
+                },
+            ),
+            (
+                ["-o", "--output"],
+                {
+                    "help": "(optional) Output graphml file for the diff input 1 - input 2",
+                    "default": None,
+                    "type": str,
+                    "required": False,
+                },
+            ),
+            (
+                ["-o2", "--output2"],
+                {
+                    "help": "(optional) Output graphml file for the diff input 2 - input 1",
+                    "default": None,
+                    "type": str,
+                    "required": False,
+                },
+            ),
+            (
+                ["-m", "--mode"],
+                {
+                    "help": 'Diff mode. There are currently two available modes "matrix" and "union".',
+                    "default": "matrix",
+                    "type": str,
+                },
+            ),
+        ],
+    )
+    def graphdiff(self):
+        """ """
+        args = self.app.pargs
+        graphDiff(self.app.config, args)
+
     @cement.ex(
         help="SBML to BNGL translator",
         arguments=[
